@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 import os
-from pefile import PE, PEFormatError
+from pefile import PE
 from peutils import SignatureDatabase
 
 
@@ -11,15 +11,22 @@ __log = lambda l, m, lvl="debug": getattr(l, lvl)(m) if l else None
 DB = os.path.join(os.path.dirname(__file__), "userdb.txt")
 
 
-def identify_packer(path, db=None, logger=None):
+def identify_packer(pe, db=None, ep_only=True, logger=None):
     """ Identify the packer used in a given executable using the given signatures database.
     
-    :param path: path to the executable file
-    :param db:   path to the database
-    :return:     return the matching packers
+    :param pe:      either the path to the executable file or a PE instance
+    :param db:      path to the database
+    :param ep_only: consider only entry point signatures
+    :return:        return the matching packers
     """
-    logger.debug("Parsing PE file '%s'..." % path)
-    return "\n".join(open_sigs(db, logger).match(PE(path), ep_only=True) or [])
+    if not isinstance(pe, PE):
+        path = pe
+        pe = PE(pe)
+        pe.path = path
+    db = open_sigs(db, logger)
+    if logger:
+        logger.debug("Parsing PE file '%s'..." % getattr(pe, "path", "unknown path"))
+    return db.match(pe, ep_only=ep_only) or []
 
 
 def open_sigs(path, logger=None):
@@ -29,7 +36,8 @@ def open_sigs(path, logger=None):
     :return:     SignatureDatabase instance
     """
     path = path or DB
-    logger.debug("Opening signature database '%s'..." % path)
+    if logger:
+        logger.debug("Opening signature database '%s'..." % path)
     with open(path, encoding="latin-1") as f:
         sigs = SignatureDatabase(data=f.read())
     return sigs
